import {
  select,
  csv,
  scaleLinear,
  max,
  scaleBand,
  axisLeft,
  axisBottom
} from 'd3';

export const barChart = (selection, props) => {
  const {
    xValue,
    yValue,
    margin,
    width,
    height,
    data
  } = props;
  
const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;
  
const xScale = scaleLinear()
  .domain([0, max(data, xValue)])
  .range([0, innerWidth]);
  
const yScale = scaleBand()
  .domain(data.map(yValue))
  .range([0, innerHeight])
  .padding(0.1);

  const g = selection.selectAll('.container').data([null]);
  const gEnter = g
    .enter().append('g')
      .attr('class', 'container');
  gEnter
    .merge(g)
      .attr('transform',
        `translate(${margin.left},${margin.top})`
      );
    
  
  const yAxis = axisLeft(yScale);
  const yAxisG = g.select('.y-axis');
  const yAxisGEnter = gEnter
    .append('g')
      .attr('class', 'y-axis');
  yAxisG
    .merge(yAxisGEnter)
      .call(yAxis);
  
const xAxis = axisBottom(xScale);
  const xAxisG = g.select('.x-axis');
  const xAxisGEnter = gEnter
  .append('g')
  .attr('class', 'x-axis');
  xAxisGEnter
    .merge(xAxisGEnter)
      .call(xAxis)
      .attr('transform', `translate(0,${innerHeight})`);
  
const rectangles = g.merge(gEnter)
      .selectAll('rect').data(data);
  rectangles
    .enter().append('rect')
    .attr('y', d => yScale(yValue(d)))
    .attr('width', d => xScale(xValue(d)))
    .attr('height', yScale.bandwidth())
  .merge(rectangles);
};