import {
  select,
  csv,
  scaleLinear,
  max,
  scaleBand,
  axisLeft,
  axisBottom
} from 'd3';

export const vertBarChart = (selection, props) => {
  const {
    xValue,
    yValue,
    margin,
    width,
    height,
    data
  } = props;
  
const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;
  
const yScale = scaleLinear()
  .domain([0, max(data, yValue)])
  .range([innerHeight,0]);
  
const xScale = scaleBand()
  .domain(data.map(xValue))
  .range([0, innerWidth]);

  const g = selection.selectAll('.container').data([null]);
  const gEnter = g
    .enter().append('g')
      .attr('class', 'container');
  gEnter
    .merge(g)
      .attr('transform',
        `translate(${margin.left},${margin.top})`
      );
    
  
  const yAxis = axisLeft(yScale);
  const yAxisG = g.select('.y-axis');
  const yAxisGEnter = gEnter
    .append('g')
      .attr('class', 'y-axis');
  yAxisG
    .merge(yAxisGEnter)
      .call(yAxis);
  
  
const rectangles = g.merge(gEnter)
      .selectAll('rect').data(data);
  rectangles
    .enter().append('rect')
    .attr('x', d => xScale(xValue(d)))
    .attr('y', d => yScale(yValue(d)))
    .attr('width', xScale.bandwidth())
    .attr('height', d => innerHeight-yScale(yValue(d)))
  .merge(rectangles);
  
  const xAxis = axisBottom(xScale);
  const xAxisG = g.select('.x-axis');
  const xAxisGEnter = gEnter
  .append('g')
  .attr('class', 'x-axis');
  xAxisGEnter
    .merge(xAxisGEnter)
      .call(xAxis)
  .selectAll("text")	
        .style("text-anchor", "end")
        // .attr("dx", "-.8em")
        // .attr("dy", "-10")
      .attr('x', d => xScale(xValue(d)))
    	.attr('y', 60)
        .attr("transform", "rotate(-90)");
      //.attr('transform', `translate(0,${innerHeight})`);
};